@@ -22,6 +22,7 @@
 #endif
 
 #include <libical-glib/i-cal-array.h>
+#include <libical-glib/libical-glib-private.h>
 
 G_DEFINE_TYPE (ICalArray, i_cal_array, I_CAL_TYPE_OBJECT)
 
@@ -147,7 +148,7 @@ i_cal_array_free (ICalArray *array)
 /**
  * i_cal_array_append:
  * @array: The #ICalArray to be appended.
- * @element: The element to be appended to the #ICalArray
+ * @element: The element to be appended to the #ICalArray. The reason why to use GOjbect * instead of gpointer is that the variable of type gpointer can only be assigned with none, integer or capsule type. The support for other types would be added in the future.
  *
  * Append @element to the end of the array
  *
@@ -156,10 +157,11 @@ i_cal_array_free (ICalArray *array)
  **/
 void
 i_cal_array_append (ICalArray *array, 
-                    gpointer element)
+                    GObject *element)
 {
 	g_return_if_fail (I_CAL_IS_ARRAY (array));
 	g_return_if_fail (array != NULL);
+	g_return_if_fail (element != NULL);
 
 	icalarray_append ((icalarray *)i_cal_object_get_native (I_CAL_OBJECT (array)), element);
 }
@@ -196,7 +198,7 @@ i_cal_array_remove_element_at (ICalArray *array,
  * Since: 1.0
  *
  **/
-const void *
+GObject *
 i_cal_array_element_at (ICalArray *array, 
                         gint position)
 {
