@@ -67,8 +67,6 @@ struct _ICalArrayClass {
 	ICalObjectClass parent;
 };
 
-ICalArray *	i_cal_array_new_full		(icalarray *native,
-						 GObject *owner);
 GType 		i_cal_array_get_type		(void);
 gint 		i_cal_array_size		(ICalArray *array);
 ICalArray *	i_cal_array_new			(gint element_size,
@@ -76,10 +74,10 @@ ICalArray *	i_cal_array_new			(gint element_size,
 ICalArray *	i_cal_array_copy		(ICalArray *array);
 void		i_cal_array_free		(ICalArray *array);
 void		i_cal_array_append		(ICalArray *array,
-						 gpointer element);
+						 GObject *element);
 void		i_cal_array_remove_element_at	(ICalArray *array,
 						 gint position);
-const void *	i_cal_array_element_at		(ICalArray *array,
+GObject *	i_cal_array_element_at		(ICalArray *array,
 						 gint position);
 void		i_cal_array_sort		(ICalArray *array,
 						 gint (*compare) (const void *, const void *));
