@@ -67,8 +67,6 @@ struct _ICalAttachClass {
 	ICalObjectClass parent;
 };
 
-ICalAttach *	i_cal_attach_new_full		(icalattach *native,
-						 GObject *owner);
 GType 		i_cal_attach_get_type		(void);
 ICalAttach *	i_cal_attach_new_from_url	(const gchar *url);
 ICalAttach *	i_cal_attach_new_from_data	(const gchar *data,
