@@ -67,10 +67,7 @@ struct _ICalCompIterClass {
 	ICalObjectClass parent;
 };
 
-ICalCompIter *	i_cal_comp_iter_new_full	(struct icalcompiter native);
 GType 		i_cal_comp_iter_get_type	(void);
-struct icalcompiter 
-		i_cal_comp_iter_new_default	(void);
 
 G_END_DECLS
 
