@@ -78,8 +78,6 @@ typedef struct _ICalTimezone ICalTimezone;
 typedef struct _ICalProperty ICalProperty;
 typedef struct _ICalDurationType ICalDurationType;
 
-ICalComponent *	i_cal_component_new_full	(icalcomponent *native,
-						 GObject *owner);
 GType 		i_cal_component_get_type	(void);
 ICalComponent *	i_cal_component_new		(ICalComponentKind kind);
 ICalComponent *	i_cal_component_new_clone	(ICalComponent *component);
