@@ -72,14 +72,8 @@ struct _ICalDatetimeperiodTypeClass {
 typedef struct _ICalTimetype ICalTimetype;
 typedef struct _ICalPeriodType ICalPeriodType;
 
-ICalDatetimeperiodType *
-		i_cal_datetimeperiod_type_new_full
-						(struct icaldatetimeperiodtype native);
 GType 		i_cal_datetimeperiod_type_get_type
 						(void);
-struct icaldatetimeperiodtype 
-		i_cal_datetimeperiod_type_new_default
-						(void);
 ICalTimetype *	i_cal_datetimeperiod_type_get_time
 						(ICalDatetimeperiodType *dtp);
 void		i_cal_datetimeperiod_type_set_time
