@@ -22,6 +22,7 @@
 #endif
 
 #include <libical-glib/i-cal-parameter.h>
+#include <libical-glib/libical-glib-private.h>
 #include <libical-glib/i-cal-derived-parameter.h>
 
 G_DEFINE_TYPE (ICalParameter, i_cal_parameter, I_CAL_TYPE_OBJECT)
@@ -222,7 +223,7 @@ i_cal_parameter_isa_parameter (ICalParameter *param)
 
 /**
  * i_cal_parameter_set_xname:
- * @param: (in-out): The #ICalParameter of which the xname to be set.
+ * @param: The #ICalParameter of which the xname to be set.
  * @v: The name to be set into the @param.
  *
  * Set the xname property of the native part of the #ICalParameter.
@@ -263,7 +264,7 @@ i_cal_parameter_get_xname (ICalParameter *param)
 
 /**
  * i_cal_parameter_set_xvalue:
- * @param: (in-out): The #ICalParameter of which the xvalue to be set.
+ * @param: The #ICalParameter of which the xvalue to be set.
  * @v: The value to be set into the @param.
  *
  * Set the xvalue property of the native part of the #ICalParameter.
@@ -304,7 +305,7 @@ i_cal_parameter_get_xvalue (ICalParameter *param)
 
 /**
  * i_cal_parameter_set_iana_name:
- * @param: (in-out): The #ICalParameter of which the iana_name to be set.
+ * @param: The #ICalParameter of which the iana_name to be set.
  * @v: The name to be set into the @param.
  *
  * Set the iana_name property of the native part of the #ICalParameter.
@@ -345,7 +346,7 @@ i_cal_parameter_get_iana_name (ICalParameter *param)
 
 /**
  * i_cal_parameter_set_iana_value:
- * @param: (in-out): The #ICalParameter of which the iana_value to be set.
+ * @param: The #ICalParameter of which the iana_value to be set.
  * @v: The value to be set into the @param.
  *
  * Set the iana_value property of the native part of the #ICalParameter.
