@@ -68,8 +68,6 @@ struct _ICalParameterClass {
 	ICalObjectClass parent;
 };
 
-ICalParameter *	i_cal_parameter_new_full	(icalparameter *native,
-						 GObject *owner);
 GType 		i_cal_parameter_get_type	(void);
 ICalParameter *	i_cal_parameter_new		(ICalParameterKind v);
 ICalParameter *	i_cal_parameter_new_clone	(ICalParameter *p);
