@@ -73,8 +73,6 @@ struct _ICalPropertyClass {
 typedef struct _ICalValue ICalValue;
 typedef struct _ICalParameter ICalParameter;
 
-ICalProperty *	i_cal_property_new_full		(icalproperty *native,
-						 GObject *owner);
 GType 		i_cal_property_get_type		(void);
 ICalProperty *	i_cal_property_new		(ICalPropertyKind kind);
 ICalProperty *	i_cal_property_new_clone	(ICalProperty *prop);
