@@ -68,14 +68,10 @@ struct _ICalReqstatTypeClass {
 	ICalObjectClass parent;
 };
 
-ICalReqstatType *
-		i_cal_reqstat_type_new_full	(struct icalreqstattype native);
 GType 		i_cal_reqstat_type_get_type	(void);
 ICalReqstatType *
 		i_cal_reqstat_type_from_string	(const gchar *str);
 gchar *		i_cal_reqstat_type_as_string_r	(ICalReqstatType *stat);
-struct icalreqstattype 
-		i_cal_reqstat_type_new_default	(void);
 ICalRequestStatus 
 		i_cal_reqstat_type_get_code	(ICalReqstatType *reqstat);
 void		i_cal_reqstat_type_set_code	(ICalReqstatType *reqstat,
