@@ -71,12 +71,8 @@ typedef struct _ICalTimetype ICalTimetype;
 typedef struct _ICalArray ICalArray;
 typedef struct _ICalComponent ICalComponent;
 
-ICalTimezone *	i_cal_timezone_new_full		(icaltimezone *native,
-						 GObject *owner,
-						 gboolean is_global_memory);
 GType 		i_cal_timezone_get_type		(void);
 ICalTimezone *	i_cal_timezone_new		(void);
-void		i_cal_timezone_destroy		(icaltimezone *zone);
 ICalTimezone *	i_cal_timezone_copy		(const ICalTimezone *zone);
 void		i_cal_timezone_free		(ICalTimezone *zone,
 						 gint free_struct);
