@@ -1,6 +1,24 @@
 #!/usr/bin/env python3
 #GI_TYPELIB_PATH=$PREFIX/lib/girepository-1.0/ ./recurrence-type.py
 
+###############################################################################
+#
+# Copyright (C) 2015 William Yu <williamyu@gnome.org>
+#
+# This library is free software: you can redistribute it and/or modify it
+# under the terms of version 2.1. of the GNU Lesser General Public License
+# as published by the Free Software Foundation.
+#
+# This library is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+# for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this library. If not, see <http://www.gnu.org/licenses/>.
+#
+###############################################################################
+
 from gi.repository import ICalGLib
 
 weekday = ICalGLib.RecurrenceType.day_day_of_week (0);
@@ -17,23 +35,29 @@ recurrence = ICalGLib.RecurrenceType.from_string (string);
 assert (recurrence.as_string_r() == "FREQ=DAILY;COUNT=10");
 
 by_second = recurrence.get_by_second();
-assert len(by_second) == 61;
+# The value is dependent on the libical version.
+assert len(by_second) == 61 or len(by_second) == 62;
 by_minute = recurrence.get_by_minute();
 assert len(by_minute) == 61;
 by_hour = recurrence.get_by_hour();
 assert len(by_hour) == 25;
 by_day = recurrence.get_by_day();
-assert len(by_day) == 364;
+# The value is dependent on the libical version.
+assert len(by_day) == 364 or len(by_day) == 386;
 by_month_day = recurrence.get_by_month_day();
 assert len(by_month_day) == 32;
 by_year_day = recurrence.get_by_year_day();
-assert len(by_year_day) == 367;
+# The value is dependent on the libical version.
+assert len(by_year_day) == 367 or len(by_year_day) == 386;
 by_week_no = recurrence.get_by_week_no();
-assert len(by_week_no) == 54;
+# The value is dependent on the libical version.
+assert len(by_week_no) == 54 or len(by_week_no) == 56;
 by_month = recurrence.get_by_month();
-assert len(by_month) == 13;
+# The value is dependent on the libical version.
+assert len(by_month) == 13 or len(by_month) == 14;
 by_set_pos = recurrence.get_by_set_pos();
-assert len(by_set_pos) == 367;
+# The value is dependent on the libical version.
+assert len(by_set_pos) == 367 or len(by_set_pos) == 386;
 
 recurrence.set_by_second(0, 1);
 by_second = recurrence.get_by_second();
@@ -64,4 +88,4 @@ while day != 0:
     ref += 1;
     timetype = iter.next();
     day = timetype.get_day();
-    
\ No newline at end of file
+    
